@@ -1,4 +1,8 @@
 from .base_factory import BaseFactory
+from .contact_filter_and_email import ContactFilterAndEmailFactory
+from .contact_filter_and_email_and_linkedin import (
+    ContactFilterAndEmailAndLinkedinFactory,
+)
 from .contact_filter_and_linkedin import ContactFilterAndLinkedinFactory
 from .default_filter_and_email import DefaultFilterAndEmailFactory
 from .default_filter_and_email_and_linkedin import (
